*************************************************************
* FIGURE 5 - Marginal effects drawn from Model 4 in Table 4
*************************************************************


***** FC GROWTH AS MODIFYING - Left panel

clear all

cd "~/QJPS_Replication"

use "replication_data_2.dta", clear

* Dependent Variable
gen fd_rail = d.railtons_1000_people

* Key Covariates
gen fd_incometax_2 = d.incometax_2
gen inter = t_ave*fd_incometax_2


reg fd_rail t_ave fd_incometax_2 inter l.railtons_1000_people i.ccode gdpcap war ipol_military ipol_urban time* participant*, robust

matrix b=e(b)
matrix V=e(V)

scalar b1=b[1,1]
scalar b3=b[1,3]

scalar varb1=V[1,1]
scalar varb3=V[3,3]

scalar covb1b3=V[1,3]

scalar list b1 b3 varb1 varb3 covb1b3

* Range of Modifying variable
* Range: from positive 15 to minus 15: it drops outliers, while covering 99% of cases.
sum fd_incometax_2
sum fd_incometax_2 if (-15>=fd_incometax_2 | fd_incometax_2 <=15)
di 1280/1288
gen tool = ((_n-1)/45)
generate MVZ= -15 + tool
sum MVZ fd_incometax_2


gen conbx=b1+b3*MVZ
gen consx=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ)
gen ax=1.65*consx
gen upperx=conbx+ax
gen lowerx=conbx-ax

* Produce marginal effect plot for X.
twoway (line conbx MVZ, lwidth(thick) lcolor(black)) (line upperx  MVZ, lcolor(grey) lpattern(dash_dot)) (line lowerx  MVZ, lcolor(grey) lpattern(dash_dot)), xlabel(-15(3)15) xtitle(Fiscal Capacity Growth (%)) ytitle("Effect of Protection on" "the Expansion of Rail Freight per Capita") legend(off) yline(0, lcolor(black)) xtitle(, size(large)) ytitle(, size(medium)) graphregion(fcolor(white))



****** PROTECTION AS MODIFYING - Right Panel

clear all

cd "/Users/Didac/Dropbox/Synchronized/Dynamic_revisited/QJPS_Replication/"

use "replication_data_2.dta", clear

* Dependent variable
gen fd_rail = d.railtons_1000_people

* Key Covariates
gen fd_incometax = d.incometax_2
gen inter = t_ave*fd_incometax


reg fd_rail fd_incometax t_ave inter l.railtons_1000_people i.ccode gdpcap war ipol_military ipol_urban time* participant*, robust


matrix b=e(b)
matrix V=e(V)

scalar b1=b[1,1]
scalar b3=b[1,3]

scalar varb1=V[1,1]
scalar varb3=V[3,3]

scalar covb1b3=V[1,3]

scalar list b1 b3 varb1 varb3 covb1b3

* Range of Modifying variable
  
sum t_ave
generate MVZ= 0 + ((_n-1)/4000)
gen conbx=b1+b3*MVZ
gen consx=sqrt(varb1+varb3*(MVZ^2)+2*covb1b3*MVZ)
gen ax=1.65*consx
gen upperx=conbx+ax
gen lowerx=conbx-ax

* Marginal effect plot
twoway (line conbx MVZ, lwidth(thick) lcolor(black)) (line upperx  MVZ, lcolor(grey) lpattern(dash_dot)) (line lowerx  MVZ, lcolor(grey) lpattern(dash_dot)), xlabel(0(.1).3) xtitle(Tariff Protection) ytitle("Effect of Fiscal Capacity Growth on" "the Expansion of Rail Freight per Capita") legend(off) yline(0, lcolor(black)) xtitle(, size(large)) ytitle(, size(medium)) graphregion(fcolor(white))


