clear all

cd "~/QJPS_Replication/"
**********************************
* POSITIVE CHANGE ONLY
**********************************

* Positive changes only, and Setting income tax to 0 when it does not exist in country i but has already been invented. 

use "replication_data_2.dta", clear

tsset ccode year

*Reforms in Positive Direction (dep var)
generate change_mag_positive=d.incometax_2
replace change_mag_positive=0 if d.incometax_2 <= 0 & d.incometax_2 !=.

* Key Covariates
gen lag_incometax_2 = l.incometax_2
gen inter_lag_incometax_2_polity2 = lag_incometax_2*polity2


* Country fixed effect
tab country, gen(ctr)


* Model 1 - big sample (year FE)
areg change_mag_positive polity2 lag_incometax_2 inter_lag_incometax_2_polity2 gdpcap war participant* ctr*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex",  replace dec(3) tex(frag) ctitle(Positive, Changes) drop(ctr* participant*) addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)

* Model 2 - small sample
areg change_mag_positive polity2 lag_incometax_2 inter_lag_incometax_2_polity2 gdpcap war t_ave ipol_urban ipol_military ipol_school02 participant* ctr*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex", dec(3) tex(frag) ctitle(Positive, Changes) drop(ctr* participant*) addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)

* Model 3 - big sample (flex)
reg change_mag_positive polity2 lag_incometax_2 inter_lag_incometax_2_polity2 gdpcap war ctr* time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex", dec(3) tex(frag) ctitle(Positive, Changes)drop(ctr* time* participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)

* Model 4 - small sample (flex ) - Notice that WW-FE drop because of collinearity
reg change_mag_positive polity2 lag_incometax_2 inter_lag_incometax_2_polity2  gdpcap war participant* t_ave ipol_urban ipol_military ipol_school02 ctr* time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex", dec(3) tex(frag) ctitle(Positive, Changes) drop(ctr* time* participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)


********************************
* POSITIVE AND NEGATIVE CHANGE
********************************
cd "~/QJPS_Replication/"

* Positive and negative changes, and Setting income tax to 0 when it does not exist in country i but has already been invented. 

use "replication_data_2.dta", clear

tsset ccode year

* Country fixed effect
tab country, gen(ctr)

*Reforms in Positive and Negative Direction (dep var)
generate change_mag_any=d.incometax_2

* Key Covariates
gen lag_incometax_2 = l.incometax_2
gen inter_lag_incometax_2_polity2 = lag_incometax_2*polity2


* Model 5 - big sample (year FE)
areg change_mag_any polity2 lag_incometax_2 inter_lag_incometax_2_polity2 gdpcap war participant* ctr*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex",  dec(3) tex(frag) ctitle(Positive and, Negative, Changes) drop(ctr* participant*) addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)

* Model 6 - small sample
areg change_mag_any polity2 lag_incometax_2 inter_lag_incometax_2_polity2 gdpcap war t_ave ipol_urban ipol_military ipol_school02 ctr* participant*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex",   dec(3) tex(frag) ctitle(Positive and, Negative, Changes)  drop(ctr* participant*) addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)


* Model 7 - big sample (flex)
reg change_mag_any polity2 lag_incometax_2 inter_lag_incometax_2_polity2 gdpcap war ctr* time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex", dec(3) tex(frag) ctitle(Positive and, Negative, Changes)   drop(ctr* time* participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)

* Model 8 - small sample (flex )
reg change_mag_any polity2 lag_incometax_2 inter_lag_incometax_2_polity2  gdpcap war t_ave ipol_urban ipol_military ipol_school02 ctr* time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H1_Results/hypothesis_1_models.tex", dec(3) tex(frag) ctitle(Positive and, Negative, Changes)   drop(ctr* time* participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)

