
clear all

cd "~/QJPS_Replication/"

use "replication_data_2.dta"

tset ccode year 

**************************
* H2 - RAIL FREIGHT
**************************

* First Difference
gen fd_rail = d.railtons_1000_people
gen fd_incometax_2 = d.incometax_2

* Country fixed effect
tab country, gen(ctr)

* Interaction
gen t_ave_fd_incometax_2 = t_ave*fd_incometax_2

* No controls
areg fd_rail t_ave fd_incometax_2 t_ave_fd_incometax_2 ctr* participant*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex", replace dec(3) tex(frag) ctitle(Growth, Rail Freight, per Capita) drop(ctr* participant*)  addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)

* Lagged stock of Rail (growth rate might differ depending on level)
areg fd_rail t_ave fd_incometax_2 t_ave_fd_incometax_2 l.railtons_1000_people ctr* participant*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex",  dec(3) tex(frag) ctitle(Growth, Rail Freight, per Capita) drop(ctr* participant*)  addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)

* Controls
areg fd_rail t_ave fd_incometax_2 t_ave_fd_incometax_2 l.railtons_1000_people ctr* gdpcap war ipol_military ipol_school ipol_urban participant*, absorb(year) robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex",  dec(3) tex(frag) ctitle(Growth, Rail Freight, per Capita) drop(ctr* participant*) addtext(Country FE, YES, Year FE, YES, Flex Polynomial, NO, WW Indicator, YES)

* Flexible Polynomial
reg fd_rail t_ave fd_incometax_2 t_ave_fd_incometax_2 l.railtons_1000_people ctr* gdpcap war ipol_military ipol_school ipol_urban  time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex",  dec(3) tex(frag) ctitle(Growth, Rail Freight, per Capita) drop(ctr* time* participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)


*********************************
* H2 - ELECTRIC POWER
*********************************

tsset ccode year

* First Difference
gen fd_elecprod_th_pop = d.elecprod_TWhr_th_pop

* Benchmark
reg fd_elecprod_th_pop t_ave fd_incometax_2 t_ave_fd_incometax_2  ctr* time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex",  dec(3) tex(frag) ctitle(Growth of, Electrict Energy, per Capita) drop(ctr* time*  participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)

* Lagged Stock
reg fd_elecprod_th_pop t_ave fd_incometax_2 t_ave_fd_incometax_2 l.elecprod_TWhr_th_pop ctr* time* participant*, robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex",  dec(3) tex(frag) ctitle(Growth of, Electrict Energy, per Capita) drop(ctr* time*  participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)

* Controls
reg fd_elecprod_th_pop t_ave fd_incometax_2 t_ave_fd_incometax_2 l.elecprod_TWhr_th_pop ctr* gdpcap war ipol_military ipol_school ipol_urban time* participant* , robust
outreg2 using "~/QJPS_Replication/QJPS_H2_Results/hypothesis_2_models.tex",  dec(3) tex(frag) ctitle(Growth of, Electrict Energy, per Capita) drop(ctr* time*  participant*) addtext(Country FE, YES, Year FE, NO, Flex Polynomial, YES, WW Indicator, YES)



