clear all

cd "~/QJPS_Replication"

use "replication_data_1.dta"

tset ccode year

***************
* Banks Data
***************

* Interpolation of Banks data, which affects all WW years.

* School
	bysort country: ipolate school02 year, gen(ipol_school02)
* Military per capita
	bysort country: ipolate military4 year, gen(ipol_military4)
* Urban population 
	bysort country: ipolate urban02 year, gen(ipol_urban02)


* Scale data

	gen tool1 = ipol_school02
	gen tool2 = ipol_urban02
		
	drop ipol_school02 
	drop ipol_urban02
	
	gen ipol_school02 = tool1/1000
	gen ipol_urban02 = tool2/1000
	
	drop tool*


*********************
* Polity Data
*********************

* Polity ranges from -10 to 10.
replace polity = . if polity > 10
replace polity = . if polity <-10


********************************
* Flora et al. income tax data
********************************

* I follow Aidt and Jensen's (2009, JPE) criterium: I set the income tax to 0 starting after the Napoleonic Wars until the first record of IT revenue. 

gen incometax_2 = incometax
replace incometax_2 = 0 if country == "Austria/Austria-Hungary" & year < 1848
replace incometax_2 = 0 if country == "Belgium" & year < 1922	
replace incometax_2 = 0 if country == "Denmark" & year < 1903
replace incometax_2 = 0 if country == "France" & year < 1914
replace incometax_2 = 0 if country == "Germany" & year < 1920
replace incometax_2 = 0 if country == "Italy" & year < 1864
replace incometax_2 = 0 if country == "Netherlands" & year < 1894
replace incometax_2 = 0 if country == "Norway" & year < 1892
replace incometax_2 = 0 if country == "Sweden" & year < 1902
replace incometax_2 = 0 if country == "Switzerland" & year < 1939
replace incometax_2 = 0 if country == "Denmark" & year < 1903
replace incometax_2 = 0 if country == "United Kingdom" & year < 1842

* CODING DECISION TO AVOID MISSINGS
replace incometax_2 = 0 if country == "Austria/Austria-Hungary" & year < 1898

* See Supplementary test for H1 to see that this coding decisions do not affect the results.

**************
* COW data
**************

* World Wars

replace war = 1 if country == "Austria/Austria-Hungary" & year >= 1914 & year <= 1919 
replace war = 1 if country == "Austria/Austria-Hungary" & year >= 1939 & year <= 1945 

replace war = 1 if country == "Denmark" & year >= 1939 & year <= 1945 
replace war = 1 if country == "France" & year >= 1939 & year <= 1945 
replace war = 1 if country == "Italy" & year >= 1939 & year <= 1945 
replace war = 1 if country == "Norway" & year >= 1939 & year <= 1945 


* PARTICIPANTS IN WW1 AND WW2

*  Source: http://en.wikipedia.org/wiki/Participants_in_World_War_I

gen participant_ww1 = 0

replace participant_ww1 = 1 if (country == "Austria/Austria-Hungary" | country == "Belgium" | country == "France" | country == "Germany" | country == "Italy" | country == "United Kingdom") & (year >= 1914 & year<=1918)

gen participant_ww2 = 0

replace participant_ww2 = 1 if (country == "Austria/Austria-Hungary" | country == "Belgium" | country == "France" | country == "Germany" | country == "Italy" | country == "United Kingdom" | country == "Netherlands" |  country == "Norway" | country == "Denmark")  & (year >= 1939 & year<=1945)



**********************
* ADDITIONAL CODING
**********************

tset ccode year

* Protection: augment Lampe data with Clemmens and William data 
	replace t_ave = duty if country == "Austria/Austria-Hungary"

* Madison variables
 	gen gdpcap = ipol_gdp/ipol_pop


** Flexible Polynomial 
	gen time = year - 1815
	gen time2 = time*time
	gen time3 = time*time*time 

	tsset ccode year
	
	
*************
* Technologies - H2
***************

	
* Rail Tons Per Thousand individual
	sum railt*
	gen thousand_people = ipol_pop/1000
	gen railtons_1000_people= (railt/thousand_people)
	sum railtons_1000_people
	
	gen lnrailtons_1000_people = ln(railtons_1000_people)


* Electricity per capita
	
	* From Kilowatt to megawatt
	
	gen elecprod_tera_watt_hr = elecprod/1000000000
	
	* Tera watt per thousand peopled
	
	gen elecprod_TWhr_th_pop = elecprod_tera_watt_hr/thousand_people

	
*****************
* FINAL SAMPLE
*******************
	
* First point: Napoleonic War (IT technology)

	drop if year<1815

* End point: 1950

	drop if year>1950

* Statehood	
	drop if country == "Germany" & year < 1871
	drop if country == "Italy" & year<1861
	drop if country == "Belgium" & year< 1830

	
save "replication_data_2.dta", replace



